print_log

Function print_log 

pub fn print_log(
    level: LogLevel,
    message: Arguments<'_>,
    params: LogParameters,
) -> String
Prints a message at the given log level into an owned string, using the provided parameters to control how the log message is formatted.