Sdp

Struct Sdp 

pub struct Sdp {
    pub ptr: *mut RawSdp,
}
An SDP session description.

Fields

ptr: *mut RawSdp

Implementations

Source

impl Sdp

pub unsafe fn new(ptr: *mut RawSdp) -> Option<Self>

pub fn parse(offer: &CStr) -> Result<Self, SdpParseError>

Parses an SDP offer string from a client into a structured SDP object.

pub fn get_payload_type(&self, codec_name: &CStr) -> Option<i32>

Gets the payload type number for a codec in this SDP, or None if the codec isn’t present.

pub fn get_payload_type_full( &self, codec_name: &CStr, profile: &CStr, ) -> Option<i32>

Gets the payload type number for a codec and provided video profile in this SDP, or None if the codec isn’t present with the provided video profile.

pub fn add_attribute(&mut self, pt: i32, name: &CStr, contents: &CStr)

Adds an attribute for the m-line with the given payload type.

pub fn rewrite_payload_type(&mut self, from: i32, to: i32)

Rewrites any references from one dynamically assigned payload type in this SDP to another dynamically assigned payload type.

pub fn get_mlines(&self) -> HashMap<MediaType, Vec<&mut RawMLine>>

Returns a map of all the SDP media lines per SDP media type.

pub fn to_glibstring(&self) -> GLibString

Writes this SDP into an owned C-style string.